==> kpeggy-0.2.tar.gz: kpeggy-0.2/kpeggy/milist.h <==
/***************************************************************************
                          milist.h  -  description
                             -------------------
    begin                : Thu Nov 22 2001
    copyright            : (C) 2001 by Jos?Pablo Fern?dez
    email                : jpablo@localhost.localdomain
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MILIST_H
#define MILIST_H

#include <qlist.h>

#include "tree.h"


/**
  *@author Jos?Pablo Fern?dez
  */

class MiList : public QList<Tree<AStarData> >  {
public: 
	MiList() { };
	~MiList() { } ;
	int compareItems(QCollection::Item  item1, QCollection::Item item2) {
		int f1, f2 ;

		
		f1 =(((Tree<AStarData> *)item1)->data())->get_g() + (((Tree<AStarData> *)item1)->data())->get_h() ;
		f2 = (((Tree<AStarData> *)item2)->data())->get_g() + (((Tree<AStarData> *)item2)->data())->get_h() ;
/*
		f1 = ((Tree<MiData> *)item1)->data().get_h() ;
		f2 = ((Tree<MiData> *)item2)->data().get_h() ;
*/
	
		return (f1 - f2) ;
	}
	
	void inSort(Tree<AStarData> *data) {
		Tree<AStarData> *aux ;
		int pos = 0;

		
		for (aux=first(); aux != null ; aux=next()) {
			if (compareItems(data, aux) <= 0) {
				insert(pos, data) ;
				return ;
			}
			pos++ ;
		}
		append(data) ;		
	}
	

}	 ;

#endif

==> kpeggy-0.3.tar.gz: kpeggy-0.3/kpeggy/milist.h <==
/***************************************************************************
                          milist.h  -  description
                             -------------------
    begin                : Thu Nov 22 2001
    copyright            : (C) 2001 by Jos Pablo Fernndez
    email                : jpablo@di.uc3m.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MILIST_H
#define MILIST_H

#include <qlist.h>

#include "tree.h"


/**
  *@author JJos Pablo Fernndez
  */

class MiList : public QList<Tree<AStarData> >  {
public: 
	MiList() { };
	~MiList() { } ;
	int compareItems(QCollection::Item  item1, QCollection::Item item2) {
		int f1, f2 ;

		
		f1 =(((Tree<AStarData> *)item1)->data())->get_g() + (((Tree<AStarData> *)item1)->data())->get_h() ;
		f2 = (((Tree<AStarData> *)item2)->data())->get_g() + (((Tree<AStarData> *)item2)->data())->get_h() ;
/*
		f1 = ((Tree<MiData> *)item1)->data().get_h() ;
		f2 = ((Tree<MiData> *)item2)->data().get_h() ;
*/
	
		return (f1 - f2) ;
	}
	
	void inSort(Tree<AStarData> *data) {
		Tree<AStarData> *aux ;
		int pos = 0;

		
		for (aux=first(); aux != null ; aux=next()) {
			if (compareItems(data, aux) <= 0) {
				insert(pos, data) ;
				return ;
			}
			pos++ ;
		}
		append(data) ;		
	}
	

}	 ;

#endif
